Range-v3: ranges::v3::range_access::RandomAccessCursorConcept Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

All Classes Files Functions Typedefs Modules Pages
Public Member Functions | List of all members
ranges::v3::range_access::RandomAccessCursorConcept Struct Reference
Inheritance diagram for ranges::v3::range_access::RandomAccessCursorConcept:

## Public Member Functions
template<typename T >
auto | requires_ (T &&t) -> decltype(concepts::valid_expr(concepts::model_of< concepts::SignedIntegral >(t.distance_to(t)),(t.advance(t.distance_to(t)), concepts::void_)))
Public Member Functions inherited from ranges::v3::concepts::refines< BidirectionalCursorConcept >
void | requires_ (Ts &&...)

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< BidirectionalCursorConcept >
using | base_concepts_t = meta::list< Concepts...>